==> forms-v5.2.1.tar.gz: forms/l10n/th.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "ฟอร์ม",
    "{user} has shared the form {formTitle} with you" : "{user} ได้แชร์ฟอร์ม {formTitle} กับคุณ",
    "{user} has shared the form {formTitle} with group {group}" : "{user} ได้แชร์ฟอร์ม {formTitle} กับกลุ่ม {group}",
    "Anonymous user" : "ผู้ใช้ไม่ระบุชื่อ",
    "A form has been <strong>shared</strong> with you" : "มีฟอร์มที่ถูก<strong>แชร์</strong>กับคุณ",
    "Someone <strong>answered</strong> a form" : "มีคน<strong>ตอบ</strong>ฟอร์ม",
    "No" : "ไม่ตกลง",
    "Yes" : "ใช่",
    "Copy" : "คัดลอก",
    "Anonymous response" : "การตอบกลับไม่ระบุตัวตน",
    "Shared by %s" : "แชร์โดย %s",
    "responses" : "การตอบกลับ",
    "User ID" : "ไอดีผู้ใช้งาน",
    "User display name" : "ชื่อที่แสดง",
    "Timestamp" : "ประทับเวลา",
    "An error occurred while loading the forms list" : "เกิดข้อผิดพลาดขณะโหลดรายการฟอร์ม",
    "Form not found" : "ไม่พบฟอร์ม",
    "Unable to create a new form" : "ไม่สามารถสร้างฟอร์มใหม่",
    "Unable to copy form" : "ไม่สามารถคัดลอกฟอร์ม",
    "New form" : "ฟอร์มใหม่",
    "Shared with you" : "แชร์กับคุณ",
    "Loading forms …" : "กำลังโหลดฟอร์ม …",
    "No forms created yet" : "ยังไม่มีฟอร์มที่สร้าง",
    "Create a form" : "สร้างฟอร์มใหม่",
    "Select a form or create a new one" : "เลือกฟอร์มหรือสร้างฟอร์มใหม่",
    "Create new form" : "สร้างฟอร์มใหม่",
    "This form does not exist" : "ไม่มีฟอร์มนี้",
    "Form expired" : "ฟอร์มหมดอายุ",
    "This form has expired and is no longer taking answers" : "ฟอร์มนี้หมดอายุแล้วและไม่รับคำตอบเพิ่มอีก",
    "Select groups" : "เลือกกลุ่ม",
    "Delete form" : "ลบฟอร์ม",
    "Error while deleting {title}" : "เกิดข้อผิดพลาดขณะลบ {title}",
    "Results" : "ผลลัพธ์",
    "Copy form" : "คัดลอกฟอร์ม",
    "Are you sure you want to delete {title}?" : "คุณแน่ใจที่จะลบ {title} หรือไม่",
    "Cancel" : "ยกเลิก",
    "Options" : "ตัวเลือก",
    "Error while saving the answer" : "ข้อผิดพลาดขณะบันทึกคำตอบ",
    "Delete answer" : "ลบคำตอบ",
    "This question needs a title!" : "คำถามนี้ต้องใส่หัวข้อ!",
    "Required" : "จำเป็น",
    "Delete question" : "ลบคำถาม",
    "Delete" : "ลบ",
    "Uploading …" : "กำลังอัปโหลด …",
    "Other" : "อื่น ๆ",
    "No response" : "ไม่มีการตอบกลับ",
    "Delete this response" : "ลบการตอบกลับนี้",
    "Expired on {date}" : "หมดอายุเมื่อ {date}",
    "Expires on {date}" : "หมดอายุตอน {date}",
    "never" : "ไม่เคย",
    "Set expiration date" : "กำหนดวันหมดอายุ",
    "Group" : "กลุ่ม",
    "Share link" : "แชร์ลิงก์",
    "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
    "View" : "มุมมอง",
    "Edit" : "แก้ไข",
    "Share" : "แชร์",
    "Loading {title} …" : "กำลังโหลด {title} …",
    "Form title" : "หัวข้อฟอร์ม",
    "Description" : "รายละเอียด",
    "Add a question" : "เพิ่มคำถาม",
    "Download" : "ดาวน์โหลด",
    "Search" : "ค้นหา",
    "Sharing" : "การแชร์",
    "Settings" : "การตั้งค่า",
    "Abort" : "ยกเลิก",
    "Submit" : "ส่ง",
    "Clear" : "ล้าง",
    "There was an error submitting the form" : "เกิดข้อผิดพลาดขณะส่งฟอร์ม",
    "Submit form" : "ส่งฟอร์ม",
    "Submitting form …" : "กำลังส่งฟอร์ม …",
    "Thank you for completing the form!" : "ขอบคุณที่ทำแบบฟอร์ม!",
    "Error while saving question" : "ข้อผิดพลาดขณะบันทึกคำถาม",
    "Form link copied" : "คัดลอกลิงก์ฟอร์มแล้ว",
    "Cannot copy, please copy the link manually" : "ไม่สามารถคัดลอก กรุณาคัดลอกลิงก์เอง",
    "No recommendations. Start typing." : "ไม่มีคำแนะนำ เริ่มพิมพ์เลย",
    "File" : "ไฟล์",
    "Short answer" : "คำถามสั้น",
    "Date" : "วันที่",
    "Pick a date" : "เลือกวันที่",
    "Datetime" : "วันที่และเวลา",
    "Pick a date and time" : "เลือกวันที่และเวลา",
    "Time" : "เวลา",
    "Color" : "สี",
    "Document" : "เอกสาร",
    "Presentation" : "งานนำเสนอ",
    "Spreadsheet" : "สเปรดชีต",
    "Text" : "ข้อความ",
    "Phone number" : "หมายเลขโทรศัพท์",
    "Email address" : "ที่อยู่อีเมล"
},
"nplurals=1; plural=0;");

==> forms-v5.2.3.tar.gz: forms/l10n/th.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "ฟอร์ม",
    "{user} has shared the form {formTitle} with you" : "{user} ได้แชร์ฟอร์ม {formTitle} กับคุณ",
    "{user} has shared the form {formTitle} with group {group}" : "{user} ได้แชร์ฟอร์ม {formTitle} กับกลุ่ม {group}",
    "Anonymous user" : "ผู้ใช้ไม่ระบุชื่อ",
    "A form has been <strong>shared</strong> with you" : "มีฟอร์มที่ถูก<strong>แชร์</strong>กับคุณ",
    "Someone <strong>answered</strong> a form" : "มีคน<strong>ตอบ</strong>ฟอร์ม",
    "No" : "ไม่ตกลง",
    "Yes" : "ใช่",
    "Copy" : "คัดลอก",
    "Anonymous response" : "การตอบกลับไม่ระบุตัวตน",
    "Shared by %s" : "แชร์โดย %s",
    "responses" : "การตอบกลับ",
    "User ID" : "ไอดีผู้ใช้งาน",
    "User display name" : "ชื่อที่แสดง",
    "Timestamp" : "ประทับเวลา",
    "An error occurred while loading the forms list" : "เกิดข้อผิดพลาดขณะโหลดรายการฟอร์ม",
    "Form not found" : "ไม่พบฟอร์ม",
    "Unable to create a new form" : "ไม่สามารถสร้างฟอร์มใหม่",
    "Unable to copy form" : "ไม่สามารถคัดลอกฟอร์ม",
    "New form" : "ฟอร์มใหม่",
    "Shared with you" : "แชร์กับคุณ",
    "No forms created yet" : "ยังไม่มีฟอร์มที่สร้าง",
    "Create a form" : "สร้างฟอร์มใหม่",
    "Select a form or create a new one" : "เลือกฟอร์มหรือสร้างฟอร์มใหม่",
    "Create new form" : "สร้างฟอร์มใหม่",
    "This form does not exist" : "ไม่มีฟอร์มนี้",
    "Form expired" : "ฟอร์มหมดอายุ",
    "This form has expired and is no longer taking answers" : "ฟอร์มนี้หมดอายุแล้วและไม่รับคำตอบเพิ่มอีก",
    "Select groups" : "เลือกกลุ่ม",
    "Delete form" : "ลบฟอร์ม",
    "Error while deleting {title}" : "เกิดข้อผิดพลาดขณะลบ {title}",
    "Results" : "ผลลัพธ์",
    "Copy form" : "คัดลอกฟอร์ม",
    "Are you sure you want to delete {title}?" : "คุณแน่ใจที่จะลบ {title} หรือไม่",
    "Cancel" : "ยกเลิก",
    "Options" : "ตัวเลือก",
    "Error while saving the answer" : "ข้อผิดพลาดขณะบันทึกคำตอบ",
    "Delete answer" : "ลบคำตอบ",
    "This question needs a title!" : "คำถามนี้ต้องใส่หัวข้อ!",
    "Required" : "จำเป็น",
    "Delete question" : "ลบคำถาม",
    "Delete" : "ลบ",
    "Other" : "อื่น ๆ",
    "No response" : "ไม่มีการตอบกลับ",
    "Delete this response" : "ลบการตอบกลับนี้",
    "Expired on {date}" : "หมดอายุเมื่อ {date}",
    "Expires on {date}" : "หมดอายุตอน {date}",
    "never" : "ไม่เคย",
    "Set expiration date" : "กำหนดวันหมดอายุ",
    "Group" : "กลุ่ม",
    "Share link" : "แชร์ลิงก์",
    "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
    "View" : "มุมมอง",
    "Edit" : "แก้ไข",
    "Share" : "แชร์",
    "Form title" : "หัวข้อฟอร์ม",
    "Description" : "รายละเอียด",
    "Add a question" : "เพิ่มคำถาม",
    "Download" : "ดาวน์โหลด",
    "Search" : "ค้นหา",
    "Sharing" : "การแชร์",
    "Settings" : "การตั้งค่า",
    "Abort" : "ยกเลิก",
    "Submit" : "ส่ง",
    "Clear" : "ล้าง",
    "There was an error submitting the form" : "เกิดข้อผิดพลาดขณะส่งฟอร์ม",
    "Submit form" : "ส่งฟอร์ม",
    "Thank you for completing the form!" : "ขอบคุณที่ทำแบบฟอร์ม!",
    "Error while saving question" : "ข้อผิดพลาดขณะบันทึกคำถาม",
    "Form link copied" : "คัดลอกลิงก์ฟอร์มแล้ว",
    "Cannot copy, please copy the link manually" : "ไม่สามารถคัดลอก กรุณาคัดลอกลิงก์เอง",
    "No recommendations. Start typing." : "ไม่มีคำแนะนำ เริ่มพิมพ์เลย",
    "File" : "ไฟล์",
    "Short answer" : "คำถามสั้น",
    "Date" : "วันที่",
    "Pick a date" : "เลือกวันที่",
    "Datetime" : "วันที่และเวลา",
    "Pick a date and time" : "เลือกวันที่และเวลา",
    "Time" : "เวลา",
    "Color" : "สี",
    "Document" : "เอกสาร",
    "Presentation" : "งานนำเสนอ",
    "Spreadsheet" : "สเปรดชีต",
    "Text" : "ข้อความ",
    "Phone number" : "หมายเลขโทรศัพท์",
    "Email address" : "ที่อยู่อีเมล",
    "Loading forms …" : "กำลังโหลดฟอร์ม …",
    "Uploading …" : "กำลังอัปโหลด …",
    "Loading {title} …" : "กำลังโหลด {title} …",
    "Submitting form …" : "กำลังส่งฟอร์ม …"
},
"nplurals=1; plural=0;");
